<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'				=> 'Instalación',
'L_WRONG_PHP_VERSION'			=> 'PluXml necesita PHP 5 o posterior',
'L_SELECT_LANG'					=> 'Seleccione su idioma',
'L_INPUT_CHANGE'				=> 'Cambiar',
'L_DEFAULT_CATEGORY_TITLE'		=> 'Categoría 1',
'L_DEFAULT_CATEGORY_URL'		=> 'categoria-1',
'L_DEFAULT_STATIC_TITLE'		=> 'Estática 1',
'L_DEFAULT_STATIC_URL'			=> 'estatica-1',
'L_DEFAULT_ARTICLE_TITLE'		=> 'Primer artículo',
'L_DEFAULT_ARTICLE_URL'			=> 'primer-articulo',
'L_DEFAULT_COMMENT_CONTENT'		=> 'Este es un primer comentario!',
'L_ERR_PLUXML_ALREADY_INSTALLED'=> 'PluXml ya está configurado!',
'L_ERR_MISSING_USER'			=> 'Indique el nombre del editor!',
'L_ERR_MISSING_LOGIN'			=> 'Indique el nombre de usuario!',
'L_ERR_MISSING_PASSWORD'		=> 'Indique una contraseña!',
'L_ERR_PASSWORD_CONFIRMATION'	=> 'La contraseña es incorrecta!',
'L_PLUXML_INSTALLATION'			=> 'Instalación de PluXml',
'L_SITE_DESCRIPTION'			=> 'Blog o CMS con XML!',
'L_VERSION'						=> 'versión',
'L_USERNAME'					=> 'Nombre del administrador',
'L_LOGIN'						=> 'Nombre de usuario del administrador',
'L_PASSWORD'					=> 'Contraseña',
'L_PASSWORD_CONFIRMATION'		=> 'Confirmar contraseña',
'L_INPUT_INSTALL'				=> 'Instalar',
'L_TIMEZONE'					=> 'Huso horario',
'L_PWD_VERY_WEAK'				=> 'Contraseña muy débil',
'L_PWD_WEAK'					=> 'Contraseña débil',
'L_PWD_GOOD'					=> 'Buena contraseña',
'L_PWD_STRONG'					=> 'Contraseña segura',
);
?>